==> react-7.7.0.tgz: package/es/EventOverlay/index.js <==
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';

var EventOverlay =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(EventOverlay, _React$Component);

  function EventOverlay() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      visibleDirection: _this.props.direction
    }, _this.componentDidMount = function () {
      _this.addHandlers();
    }, _this.componentDidUpdate = function (prevProps) {
      if (_this.props.isOpen && prevProps.isOpen !== _this.props.isOpen || prevProps.direction !== _this.props.direction) {
        return _this.forceUpdate(function () {
          return _this.isVisible();
        });
      }
    }, _this.componentWillUnmount = function () {
      _this.removeHandlers();
    }, _this.isVisible = function () {
      var _this$props = _this.props,
          direction = _this$props.direction,
          isOpen = _this$props.isOpen,
          anchorNode = _this$props.anchorNode,
          showArrow = _this$props.showArrow,
          isDynamic = _this$props.isDynamic,
          targetOffset = _this$props.targetOffset;
      if (!isOpen) return;
      if (!isDynamic) return _this.setPlacement();
      var element = ReactDOM.findDOMNode(_this.container);
      var elementAnchor = ReactDOM.findDOMNode(anchorNode);
      var alignment = direction.split('-')[1];
      var tempParentArr = [];
      var anchor = elementAnchor && elementAnchor.getBoundingClientRect();
      var elementBoundingRect = element.getBoundingClientRect();
      var elementParent = element.parentElement;
      var windowBottom = window.pageXOffset + window.innerHeight;
      var elementHeight = elementBoundingRect.height;
      var anchorBottom = anchor.bottom;
      var arrowHeight = showArrow ? ReactDOM.findDOMNode(_this.arrow).getBoundingClientRect().height : 0;
      var offsetHeight = targetOffset.height || 0;
      var totalHeight = anchorBottom + elementHeight + arrowHeight + offsetHeight;

      var findParents = function findParents(elem) {
        return !elem.parentElement ? tempParentArr : findParents(elem.parentElement, tempParentArr.push(elem));
      };

      var elementParents = findParents(elementParent);

      var findOverflow = function findOverflow(node) {
        var searchProps = ['overflow', 'overflow-y'];
        return searchProps.reduce(function (agg, prop) {
          var overflowElement = ReactDOM.findDOMNode(node).style[prop];
          return !overflowElement || agg.includes(overflowElement) ? agg : agg += overflowElement;
        }, '');
      };

      var findScrollParent = function findScrollParent() {
        var overflowElement = null;
        var idx = 0;

        while (!overflowElement && elementParents[idx]) {
          if (/(auto|scroll)/.test(findOverflow(elementParents[idx]))) {
            return overflowElement = elementParents[idx];
          }

          idx++;
        }

        return overflowElement ? overflowElement : window;
      };

      var scrollParent = findScrollParent(element);
      var parentBottom = !!scrollParent.getBoundingClientRect && scrollParent.getBoundingClientRect().bottom || windowBottom;
      return totalHeight < parentBottom && totalHeight < windowBottom ? _this.setState({
        visibleDirection: "bottom-" + alignment
      }, function () {
        return _this.setPlacement();
      }) : _this.setState({
        visibleDirection: "top-" + alignment
      }, function () {
        return _this.setPlacement();
      });
    }, _this.addHandlers = function () {
      var _this$props2 = _this.props,
          allowClickAway = _this$props2.allowClickAway,
          closeOnClick = _this$props2.closeOnClick;
      _this.handleResize = _this.isVisible;
      _this.handleScroll = _this.isVisible;
      allowClickAway && window.addEventListener('click', _this.handleAllowClickAway, true);
      closeOnClick && window.addEventListener('click', _this.handleCloseOnClick, false);
      window.addEventListener('resize', _this.handleResize, true);
      window.addEventListener('scroll', _this.handleScroll, false);
      window.addEventListener('keyup', _this.handleKeyUp, true);

      _this.isVisible();
    }, _this.removeHandlers = function () {
      window.removeEventListener('click', _this.handleAllowClickAway, true);
      window.removeEventListener('click', _this.handleCloseOnClick, false);
      window.removeEventListener('resize', _this.handleResize, true);
      window.removeEventListener('scroll', _this.handleScroll, false);
      window.removeEventListener('keyup', _this.handleKeyUp, true);
    }, _this.handleCloseOnClick = function (e) {
      if (!_this.props.isOpen) return;
      var closeOnClick = _this.props.closeOnClick;
      return closeOnClick && _this.container && ReactDOM.findDOMNode(_this.container).contains(e.target) && _this.handleClickAway(e);
    }, _this.handleKeyUp = function (e) {
      if (!_this.props.isOpen) return;
      if (e.keyCode === 27) return _this.handleClickAway(e);
      var anchorNode = ReactDOM.findDOMNode(_this.props.anchorNode);
      return _this.container && !anchorNode.contains(document.activeElement) && !ReactDOM.findDOMNode(_this.container).contains(document.activeElement) && _this.handleClickAway(e);
    }, _this.handleAllowClickAway = function (e) {
      if (!_this.props.isOpen) return;
      var anchorNode = ReactDOM.findDOMNode(_this.props.anchorNode);
      return _this.container && !ReactDOM.findDOMNode(anchorNode).contains(e.target) && !ReactDOM.findDOMNode(_this.container).contains(e.target) && _this.handleClickAway(e);
    }, _this.getAnchorPosition = function (node) {
      var rect = node.getBoundingClientRect();
      var anchorPosition = {
        top: rect.top,
        left: rect.left,
        width: node.offsetWidth,
        height: node.offsetHeight
      };
      anchorPosition.right = rect.right || anchorPosition.left + anchorPosition.width;
      anchorPosition.bottom = rect.bottom || anchorPosition.top + anchorPosition.height;
      anchorPosition.middle = anchorPosition.left + (anchorPosition.right - anchorPosition.left) / 2;
      anchorPosition.center = anchorPosition.top + (anchorPosition.bottom - anchorPosition.top) / 2;
      return anchorPosition;
    }, _this.getTargetPosition = function (targetNode) {
      return {
        top: 0,
        center: targetNode.offsetHeight / 2,
        bottom: targetNode.offsetHeight,
        left: 0,
        middle: targetNode.offsetWidth / 2,
        right: targetNode.offsetWidth
      };
    }, _this.getOrigin = function () {
      var side = _this.state.visibleDirection.split('-')[0];

      var alignment = _this.props.direction.split('-')[1];

      var origin = {
        anchor: {},
        target: {}
      };

      if (side === 'top' || side === 'bottom') {
        origin.anchor.vertical = side;
        origin.anchor.horizontal = alignment === 'center' ? 'middle' : alignment;
        origin.target.vertical = side === 'top' ? 'bottom' : 'top';
        origin.target.horizontal = alignment === 'center' ? 'middle' : alignment;
      }

      if (side === 'left' || side === 'right') {
        origin.anchor.vertical = alignment;
        origin.anchor.horizontal = side;
        origin.target.vertical = alignment;
        origin.target.horizontal = side === 'left' ? 'right' : 'left';
      }

      return origin;
    }, _this.setArrowPlacement = function (anchor) {
      var arrow = _this.arrow;
      var targetOffset = _this.props.targetOffset;
      var visibleDirection = _this.state.visibleDirection;
      var side = visibleDirection.split('-')[0];
      var verticalOffset = targetOffset.vertical || 0;
      var horizontalOffset = targetOffset.horizontal || 0;

      switch (side) {
        case 'top':
          arrow.style.left = anchor.middle + "px";
          arrow.style.top = anchor.top - verticalOffset + "px";
          break;

        case 'bottom':
          arrow.style.left = anchor.middle + "px";
          arrow.style.top = anchor.bottom + verticalOffset + "px";
          break;

        case 'left':
          arrow.style.left = anchor.left - horizontalOffset + "px";
          arrow.style.top = anchor.center + "px";
          break;

        case 'right':
          arrow.style.left = anchor.right + horizontalOffset + "px";
          arrow.style.top = anchor.center + "px";
          break;
      }
    }, _this.setPlacement = function () {
      var _this$props3 = _this.props,
          isOpen = _this$props3.isOpen,
          anchorNode = _this$props3.anchorNode,
          maxHeight = _this$props3.maxHeight,
          targetOffset = _this$props3.targetOffset;
      var visibleDirection = _this.state.visibleDirection;
      if (!isOpen) return;
      var anchorNodeFound = ReactDOM.findDOMNode(anchorNode);
      var side = visibleDirection.split('-')[0];
      var targetNode = _this.container;
      var verticalOffset = targetOffset.vertical || 0;
      var horizontalOffset = targetOffset.horizontal || 0;
      if (!targetNode || !anchorNodeFound) return;
      anchorNodeFound.link = _this.state.id;

      var anchorPosition = _this.getAnchorPosition(anchorNodeFound);

      var targetPosition = _this.getTargetPosition(targetNode);

      var origin = _this.getOrigin();

      var anchorOrigin = origin.anchor;
      var targetOrigin = origin.target;
      var targetNodePosition = {
        top: anchorPosition[anchorOrigin.vertical] - targetPosition[targetOrigin.vertical] + (side === 'top' ? -verticalOffset : verticalOffset),
        left: anchorPosition[anchorOrigin.horizontal] - targetPosition[targetOrigin.horizontal] + (side === 'left' ? -horizontalOffset : horizontalOffset)
      };
      targetNode.style.top = targetNodePosition.top + "px";
      targetNode.style.left = targetNodePosition.left + "px";
      targetNode.style.maxHeight = maxHeight && maxHeight + "px";
      _this.props.showArrow && _this.setArrowPlacement(anchorPosition);
    }, _this.handleClickAway = function (e) {
      _this.props.close && _this.props.close(e);
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = EventOverlay.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$props4 = this.props,
        className = _this$props4.className,
        isOpen = _this$props4.isOpen,
        children = _this$props4.children,
        showArrow = _this$props4.showArrow;
    var side = this.state.visibleDirection.split('-')[0];
    var contentNodes = React.createElement("div", {
      className: 'cui-event-overlay' + ("" + (showArrow && " cui-event-overlay--arrow" || '')) + ("" + (side && " cui-event-overlay--" + side || '')) + ("" + (className && " " + className || ''))
    }, showArrow && React.createElement("div", {
      ref: function ref(_ref) {
        return _this2.arrow = _ref;
      },
      className: "cui-event-overlay__arrow"
    }), React.createElement("div", {
      className: "cui-event-overlay__children",
      ref: function ref(_ref2) {
        return _this2.container = _ref2;
      }
    }, children));
    return isOpen && contentNodes;
  };

  return EventOverlay;
}(React.Component);

EventOverlay.displayName = 'EventOverlay';
export { EventOverlay as default };
EventOverlay.defaultProps = {
  allowClickAway: true,
  anchorNode: null,
  children: null,
  className: '',
  close: null,
  isDynamic: false,
  isOpen: false,
  direction: 'bottom-left',
  targetOffset: {
    horizontal: 0,
    vertical: 0
  },
  showArrow: false,
  maxHeight: null
};
EventOverlay.propTypes = {
  allowClickAway: PropTypes.bool,
  anchorNode: PropTypes.object,
  children: PropTypes.node,
  className: PropTypes.string,
  close: PropTypes.func,
  isDynamic: PropTypes.bool,
  isOpen: PropTypes.bool,
  targetOffset: PropTypes.shape({
    horizontal: PropTypes.number,
    vertical: PropTypes.number
  }),
  direction: PropTypes.oneOf(['top-center', 'left-center', 'right-center', 'bottom-center', 'top-left', 'top-right', 'bottom-left', 'bottom-right', 'left-top', 'left-bottom', 'right-top', 'right-bottom']),
  showArrow: PropTypes.bool,
  closeOnClick: PropTypes.bool,
  maxHeight: PropTypes.number
};

==> react-7.8.0.tgz: package/es/EventOverlay/index.js <==
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';

var EventOverlay =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(EventOverlay, _React$Component);

  function EventOverlay() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      visibleDirection: _this.props.direction
    }, _this.componentDidMount = function () {
      _this.addHandlers();
    }, _this.componentDidUpdate = function (prevProps) {
      if (_this.props.isOpen && prevProps.isOpen !== _this.props.isOpen || prevProps.direction !== _this.props.direction) {
        return _this.forceUpdate(function () {
          return _this.isVisible();
        });
      }
    }, _this.componentWillUnmount = function () {
      _this.removeHandlers();
    }, _this.isVisible = function () {
      var _this$props = _this.props,
          direction = _this$props.direction,
          isOpen = _this$props.isOpen,
          anchorNode = _this$props.anchorNode,
          showArrow = _this$props.showArrow,
          isDynamic = _this$props.isDynamic,
          targetOffset = _this$props.targetOffset;
      if (!isOpen) return;
      if (!isDynamic) return _this.setPlacement();
      var element = ReactDOM.findDOMNode(_this.container);
      var elementAnchor = ReactDOM.findDOMNode(anchorNode);
      var alignment = direction.split('-')[1];
      var tempParentArr = [];
      var anchor = elementAnchor && elementAnchor.getBoundingClientRect();
      var elementBoundingRect = element.getBoundingClientRect();
      var elementParent = element.parentElement;
      var windowBottom = window.pageXOffset + window.innerHeight;
      var elementHeight = elementBoundingRect.height;
      var anchorBottom = anchor.bottom;
      var arrowHeight = showArrow ? ReactDOM.findDOMNode(_this.arrow).getBoundingClientRect().height : 0;
      var offsetHeight = targetOffset.height || 0;
      var totalHeight = anchorBottom + elementHeight + arrowHeight + offsetHeight;

      var findParents = function findParents(elem) {
        return !elem.parentElement ? tempParentArr : findParents(elem.parentElement, tempParentArr.push(elem));
      };

      var elementParents = findParents(elementParent);

      var findOverflow = function findOverflow(node) {
        var searchProps = ['overflow', 'overflow-y'];
        return searchProps.reduce(function (agg, prop) {
          var overflowElement = ReactDOM.findDOMNode(node).style[prop];
          return !overflowElement || agg.includes(overflowElement) ? agg : agg += overflowElement;
        }, '');
      };

      var findScrollParent = function findScrollParent() {
        var overflowElement = null;
        var idx = 0;

        while (!overflowElement && elementParents[idx]) {
          if (/(auto|scroll)/.test(findOverflow(elementParents[idx]))) {
            return overflowElement = elementParents[idx];
          }

          idx++;
        }

        return overflowElement ? overflowElement : window;
      };

      var scrollParent = findScrollParent(element);
      var parentBottom = !!scrollParent.getBoundingClientRect && scrollParent.getBoundingClientRect().bottom || windowBottom;
      return totalHeight < parentBottom && totalHeight < windowBottom ? _this.setState({
        visibleDirection: "bottom-" + alignment
      }, function () {
        return _this.setPlacement();
      }) : _this.setState({
        visibleDirection: "top-" + alignment
      }, function () {
        return _this.setPlacement();
      });
    }, _this.addHandlers = function () {
      var _this$props2 = _this.props,
          allowClickAway = _this$props2.allowClickAway,
          closeOnClick = _this$props2.closeOnClick;
      _this.handleResize = _this.isVisible;
      _this.handleScroll = _this.isVisible;
      allowClickAway && window.addEventListener('click', _this.handleAllowClickAway, true);
      closeOnClick && window.addEventListener('click', _this.handleCloseOnClick, false);
      window.addEventListener('resize', _this.handleResize, true);
      window.addEventListener('scroll', _this.handleScroll, false);
      window.addEventListener('keyup', _this.handleKeyUp, true);

      _this.isVisible();
    }, _this.removeHandlers = function () {
      window.removeEventListener('click', _this.handleAllowClickAway, true);
      window.removeEventListener('click', _this.handleCloseOnClick, false);
      window.removeEventListener('resize', _this.handleResize, true);
      window.removeEventListener('scroll', _this.handleScroll, false);
      window.removeEventListener('keyup', _this.handleKeyUp, true);
    }, _this.handleCloseOnClick = function (e) {
      if (!_this.props.isOpen) return;
      var closeOnClick = _this.props.closeOnClick;
      return closeOnClick && _this.container && ReactDOM.findDOMNode(_this.container).contains(e.target) && _this.handleClickAway(e);
    }, _this.handleKeyUp = function (e) {
      if (!_this.props.isOpen) return;
      if (e.keyCode === 27) return _this.handleClickAway(e);
      var anchorNode = ReactDOM.findDOMNode(_this.props.anchorNode);
      return _this.container && !anchorNode.contains(document.activeElement) && !ReactDOM.findDOMNode(_this.container).contains(document.activeElement) && _this.handleClickAway(e);
    }, _this.handleAllowClickAway = function (e) {
      if (!_this.props.isOpen) return;
      var anchorNode = ReactDOM.findDOMNode(_this.props.anchorNode);
      return _this.container && !ReactDOM.findDOMNode(anchorNode).contains(e.target) && !ReactDOM.findDOMNode(_this.container).contains(e.target) && _this.handleClickAway(e);
    }, _this.getAnchorPosition = function (node) {
      var rect = node.getBoundingClientRect();
      var anchorPosition = {
        top: rect.top,
        left: rect.left,
        width: node.offsetWidth,
        height: node.offsetHeight
      };
      anchorPosition.right = rect.right || anchorPosition.left + anchorPosition.width;
      anchorPosition.bottom = rect.bottom || anchorPosition.top + anchorPosition.height;
      anchorPosition.middle = anchorPosition.left + (anchorPosition.right - anchorPosition.left) / 2;
      anchorPosition.center = anchorPosition.top + (anchorPosition.bottom - anchorPosition.top) / 2;
      return anchorPosition;
    }, _this.getTargetPosition = function (targetNode) {
      return {
        top: 0,
        center: targetNode.offsetHeight / 2,
        bottom: targetNode.offsetHeight,
        left: 0,
        middle: targetNode.offsetWidth / 2,
        right: targetNode.offsetWidth
      };
    }, _this.getOrigin = function () {
      var side = _this.state.visibleDirection.split('-')[0];

      var alignment = _this.props.direction.split('-')[1];

      var origin = {
        anchor: {},
        target: {}
      };

      if (side === 'top' || side === 'bottom') {
        origin.anchor.vertical = side;
        origin.anchor.horizontal = alignment === 'center' ? 'middle' : alignment;
        origin.target.vertical = side === 'top' ? 'bottom' : 'top';
        origin.target.horizontal = alignment === 'center' ? 'middle' : alignment;
      }

      if (side === 'left' || side === 'right') {
        origin.anchor.vertical = alignment;
        origin.anchor.horizontal = side;
        origin.target.vertical = alignment;
        origin.target.horizontal = side === 'left' ? 'right' : 'left';
      }

      return origin;
    }, _this.setArrowPlacement = function (anchor) {
      var arrow = _this.arrow;
      var targetOffset = _this.props.targetOffset;
      var visibleDirection = _this.state.visibleDirection;
      var side = visibleDirection.split('-')[0];
      var verticalOffset = targetOffset.vertical || 0;
      var horizontalOffset = targetOffset.horizontal || 0;

      switch (side) {
        case 'top':
          arrow.style.left = anchor.middle + "px";
          arrow.style.top = anchor.top - verticalOffset + "px";
          break;

        case 'bottom':
          arrow.style.left = anchor.middle + "px";
          arrow.style.top = anchor.bottom + verticalOffset + "px";
          break;

        case 'left':
          arrow.style.left = anchor.left - horizontalOffset + "px";
          arrow.style.top = anchor.center + "px";
          break;

        case 'right':
          arrow.style.left = anchor.right + horizontalOffset + "px";
          arrow.style.top = anchor.center + "px";
          break;
      }
    }, _this.setPlacement = function () {
      var _this$props3 = _this.props,
          isOpen = _this$props3.isOpen,
          anchorNode = _this$props3.anchorNode,
          targetOffset = _this$props3.targetOffset;
      var visibleDirection = _this.state.visibleDirection;
      if (!isOpen) return;
      var anchorNodeFound = ReactDOM.findDOMNode(anchorNode);
      var side = visibleDirection.split('-')[0];
      var targetNode = _this.container;
      var verticalOffset = targetOffset.vertical || 0;
      var horizontalOffset = targetOffset.horizontal || 0;
      if (!targetNode || !anchorNodeFound) return;
      anchorNodeFound.link = _this.state.id;

      var anchorPosition = _this.getAnchorPosition(anchorNodeFound);

      var targetPosition = _this.getTargetPosition(targetNode);

      var origin = _this.getOrigin();

      var anchorOrigin = origin.anchor;
      var targetOrigin = origin.target;
      var targetNodePosition = {
        top: anchorPosition[anchorOrigin.vertical] - targetPosition[targetOrigin.vertical] + (side === 'top' ? -verticalOffset : verticalOffset),
        left: anchorPosition[anchorOrigin.horizontal] - targetPosition[targetOrigin.horizontal] + (side === 'left' ? -horizontalOffset : horizontalOffset)
      };
      targetNode.style.top = targetNodePosition.top + "px";
      targetNode.style.left = targetNodePosition.left + "px";
      _this.props.showArrow && _this.setArrowPlacement(anchorPosition);
    }, _this.handleClickAway = function (e) {
      _this.props.close && _this.props.close(e);
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = EventOverlay.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$props4 = this.props,
        className = _this$props4.className,
        isOpen = _this$props4.isOpen,
        children = _this$props4.children,
        showArrow = _this$props4.showArrow,
        maxHeight = _this$props4.maxHeight,
        maxWidth = _this$props4.maxWidth;
    var side = this.state.visibleDirection.split('-')[0];
    var contentNodes = React.createElement("div", {
      className: 'cui-event-overlay' + ("" + (showArrow && " cui-event-overlay--arrow" || '')) + ("" + (side && " cui-event-overlay--" + side || '')) + ("" + (className && " " + className || ''))
    }, showArrow && React.createElement("div", {
      ref: function ref(_ref) {
        return _this2.arrow = _ref;
      },
      className: "cui-event-overlay__arrow"
    }), React.createElement("div", {
      className: "cui-event-overlay__children",
      ref: function ref(_ref2) {
        return _this2.container = _ref2;
      },
      style: {
        maxWidth: "" + (maxWidth && maxWidth + "px" || 'none'),
        maxHeight: "" + (maxHeight && maxHeight + "px" || 'none')
      }
    }, children));
    return isOpen && contentNodes;
  };

  return EventOverlay;
}(React.Component);

EventOverlay.displayName = 'EventOverlay';
export { EventOverlay as default };
EventOverlay.defaultProps = {
  allowClickAway: true,
  anchorNode: null,
  children: null,
  className: '',
  close: null,
  isDynamic: false,
  isOpen: false,
  direction: 'bottom-left',
  targetOffset: {
    horizontal: 0,
    vertical: 0
  },
  showArrow: false,
  maxHeight: null,
  maxWidth: null
};
EventOverlay.propTypes = {
  allowClickAway: PropTypes.bool,
  anchorNode: PropTypes.object,
  children: PropTypes.node,
  className: PropTypes.string,
  close: PropTypes.func,
  isDynamic: PropTypes.bool,
  isOpen: PropTypes.bool,
  targetOffset: PropTypes.shape({
    horizontal: PropTypes.number,
    vertical: PropTypes.number
  }),
  direction: PropTypes.oneOf(['top-center', 'left-center', 'right-center', 'bottom-center', 'top-left', 'top-right', 'bottom-left', 'bottom-right', 'left-top', 'left-bottom', 'right-top', 'right-bottom']),
  showArrow: PropTypes.bool,
  closeOnClick: PropTypes.bool,
  maxHeight: PropTypes.number,
  maxWidth: PropTypes.number
};
